@@ -1,7 +1,7 @@
 import logging
 import asyncio
 import base64
-import json
+import ujson as json
 from aiohttp import ClientSession
 from scrapy.utils.misc import load_object
 from lich_linkextractor.utils import as_deferred
@@ -43,14 +43,29 @@ class AyncExtractor:
         d.addCallback(_on_success)
         d.addBoth(lambda _: response)
         return d
-    
-    async def get_links(self, rules, response):
+    def _get_base_ex_req(self, response):
+        base_ex_req=None
+        if response.request.meta.get("render_proxy.api", None) is None:
+            base_ex_req={
+                "URL":response.url,
+                "Content":to_unicode(base64.encodebytes(response.body)),
+                "ContentType":to_unicode(response.headers.get("Content-Type"))
+            }
+        else:
+            render_body = json.loads(response.body.decode('utf8'))
+            if "renderStatus" in render_body and render_body["renderStatus"]=="RENDER_OK" and\
+                render_body["httpStatus"]<300 and render_body["httpStatus"]>=200:
+                base_ex_req={
+                    "URL": render_body["url"],
+                    "Content": to_unicode(base64.encodebytes(render_body["renderPage"].encode("utf-8"))),
+                    "ContentType": "html;charset=utf-8"
+                }
+        return base_ex_req
+    async def _get_links(self, rules, response):
         res={}
-        base_ex_req={
-            "URL":response.url,
-            "Content":to_unicode(base64.encodebytes(response.body)),
-            "ContentType":to_unicode(response.headers.get("Content-Type"))
-        }        
+        base_ex_req=self._get_base_ex_req(response)
+        if base_ex_req is None:
+            return res
         for rule in rules :
             ex_req=base_ex_req
             for key in [
@@ -70,7 +85,7 @@ class AyncExtractor:
                     or isinstance(v,bool)
                 ):
                     ex_req[key_map[key]] = v
-            resp = await self.send(self.server_addr,json.dumps(ex_req),3)
+            resp = await self._send(self.server_addr,json.dumps(ex_req),3)
             s = set()
             for value in resp.values():
                 for link in value:
@@ -98,17 +113,17 @@ class AyncExtractor:
         max_depth = self._get_max_depth(req_depth_limit)
         if max_depth and depth and depth >= max_depth:
             return {}
-        links = await self.get_links(rules, response)
+        links = await self._get_links(rules, response)
         return links
 
-    async def send(self,addr,data,num_retries):
+    async def _send(self,addr,data,num_retries):
         if addr!=None and data!=None:
             async with self.client.post(addr, data=data) as response:
                 if response.status == 200:
                     return await response.json()
                 if response.status == 404:
                     if num_retries>0:
-                        return await self.send(addr, data, num_retries-1)
+                        return await self._send(addr, data, num_retries-1)
                 response.raise_for_status()
                     
     async def spider_closed(self):
